@@ -6,7 +6,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.34
+0.35
 
 =head1 SYNOPSIS
 
@@ -163,7 +163,7 @@ use File::Spec ();
 use constant CACHE_ASSETS => $ENV{MOJO_ASSETPACK_NO_CACHE} ? 0 : 1;
 use constant DEBUG => $ENV{MOJO_ASSETPACK_DEBUG} || 0;
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 =head1 ATTRIBUTES
 
@@ -354,7 +354,7 @@ sub process {
     die $e unless $self->fallback;
     $e =~ s/ at \S+.*//s;
     $self->{log}->debug("AssetPack failed, but will try fallback mode. ($e)\n");
-    $self->_fallback($moniker) or die "AssetPack could not find already packed asset '$moniker' in fallback mode.";
+    $self->_fallback($moniker) or die "AssetPack could not find already packed asset '$moniker' in fallback mode. ($e)";
   };
 
   $self;
@@ -377,6 +377,7 @@ sub register {
   my ($self, $app, $config) = @_;
   my $helper = $config->{helper} || 'asset';
 
+  $self->{mode} = $app->mode;
   $self->fallback($config->{fallback} // $app->mode eq 'production');
   $self->minify($config->{minify}     // $app->mode eq 'production');
   $self->base_url($config->{base_url}) if $config->{base_url};
@@ -469,6 +470,29 @@ sub _name_ext {
   die "Moniker ($_[1]) need to have an extension, like .css, .js, ...";
 }
 
+sub _make_error_asset {
+  my ($self, $data, $err) = @_;
+  my $file = $self->{mode} eq 'production' ? $data->{moniker} : $data->{path};
+
+  $err =~ s!\r!!g;
+  $err =~ s!\n+$!!;
+  $err = "$file: $err";
+
+  if ($data->{moniker} =~ /\.js$/) {
+    $err =~ s!'!"!g;
+    $err =~ s!\n!\\n!g;
+    $err =~ s!\s! !g;
+    return "alert('$err');console.log('$err');";
+  }
+  else {
+    $err =~ s!"!'!g;
+    $err =~ s!\n!\\A!g;
+    $err =~ s!\s! !g;
+    return
+      qq(html:before{background:#f00;color:#fff;font-size:14pt;position:absolute;padding:20px;z-index:9999;content:"$err";});
+  }
+}
+
 sub _process {
   my ($self, $moniker, @files) = @_;
   my ($md5_sum, $files) = $self->_read_files(@files);
@@ -486,14 +510,18 @@ sub _process {
 
   for my $file (@files) {
     my $data = $files->{$file};
-    my $err = $self->preprocessors->process($data->{ext}, $self, \$data->{body}, $data->{path});
 
-    $processed .= $data->{body};
-
-    if ($err) {
-      $self->{log}->error($err);
+    eval {
+      $self->preprocessors->process($data->{ext}, $self, \$data->{body}, $data->{path});
+      $processed .= $data->{body};
+      1;
+    } or do {
+      my $e = $@;
+      $self->{log}->error($e);
+      local $data->{moniker} = $moniker;
+      $processed .= $self->_make_error_asset($data, $e);
       $self->{processed}{$moniker} = ["$name-$md5_sum-with-error.$ext"];
-    }
+    };
   }
 
   $path = File::Spec->catfile($self->out_dir, $self->{processed}{$moniker}[0]);
